@@ -52,6 +52,16 @@ namespace FSpot {
 				this.Update ();
 			}
 		}
+
+		protected override void OnLinkClicked (string url)
+		{
+                        if (url.StartsWith ("/")) {
+                                // do a lame job of creating a URI out of local paths
+                                url = "file://" + url;
+                        }
+                        
+                        GnomeUtil.UrlShow (null, url);
+		}
 		
 		protected override void OnStyleSet (Gtk.Style previous)
 		{
@@ -92,6 +102,32 @@ namespace FSpot {
 			return value;
 		}
 
+		private string GetExportUrl (ExportItem export)
+		{
+			switch (export.ExportType) {
+			case ExportStore.FlickrExportType:
+				string[] split_token = export.ExportToken.Split (':');
+				return String.Format ("http://www.flickr.com/photos/{0}/{1}/", split_token[0], split_token[2]);
+			case ExportStore.FolderExportType:
+				return export.ExportToken;
+			default:
+				return null;
+			}
+		}
+
+		private string GetExportLabel (ExportItem export)
+		{
+			switch (export.ExportType) {
+			case ExportStore.FlickrExportType:
+				string[] split_token = export.ExportToken.Split (':');
+				return String.Format ("Flickr ({0})", split_token[1]);
+			case ExportStore.FolderExportType:
+				return Catalog.GetString ("Folder");
+			default:
+				return null;
+			}
+		}
+
 		private void Update ()
 		{
 			Gtk.HTMLStream stream = this.Begin (null, "text/html; charset=utf-8", Gtk.HTMLBeginFlags.Scroll);
@@ -177,7 +213,7 @@ namespace FSpot {
 #endif
 					empty = false;
 					stream.Write ("<tr><th align=left bgcolor=\"" + ig + "\" colspan=2>" 
-						      + Catalog.GetString ("Extended Metadata") + "</th><tr>");
+						      + Catalog.GetString ("Extended Metadata") + "</th></tr>");
 					
 					foreach (Statement stmt in store) {
 						// Skip anonymous subjects because they are
@@ -204,9 +240,24 @@ namespace FSpot {
 						if (value != null && value != "")
 							stream.Write (value);
 						
-						stream.Write ("</td><tr>");
+						stream.Write ("</td></tr>");
 					}
 				}
+
+				stream.Write ("<tr><th align=left bgcolor=\"" + ig + "\" colspan=2>" + Catalog.GetString ("Exported Locations") + "</th></tr>");
+
+				Photo p = photo as Photo;
+				foreach (ExportItem export in Core.Database.Exports.GetByImageId (p.Id, p.DefaultVersionId)) {
+					string url = GetExportUrl (export);
+					string label = GetExportLabel (export);
+
+					if (url == null || label == null)
+						continue;
+                                        
+					stream.Write ("<tr colspan=2><td width=100%>");
+					stream.Write (String.Format ("<a href=\"{0}\">{1}</a>", url, label));
+					stream.Write ("</font></small></td></tr>");
+				}
 			}
 			
 			if (empty) {
