@@ -16,7 +16,6 @@ public class PhotoView : EventBox {
 	private EventBox background;
 
 	private TagView tag_view;
-	private EventBox tag_view_box;
 	
 	private Button display_next_button, display_previous_button;
 	private Label count_label;
@@ -29,8 +28,6 @@ public class PhotoView : EventBox {
 	Gtk.Button desaturate_button;
 	Gtk.Button sepia_button;
 
-	FSpot.AsyncPixbufLoader loader = new FSpot.AsyncPixbufLoader ();
-
 	private OptionMenu constraints_option_menu;
 	private int selection_constraint_ratio_idx;
 	private uint restore_scrollbars_idle_id;
@@ -68,10 +65,10 @@ public class PhotoView : EventBox {
 		new SelectionConstraint (Catalog.GetString ("4 x 6 (Postcard)"), 6.0 / 4.0),
 		new SelectionConstraint (Catalog.GetString ("5 x 7 (L, 2L)"), 7.0 / 5.0),
 		new SelectionConstraint (Catalog.GetString ("8 x 10"), 10.0 / 8.0),
-		new SelectionConstraint (Catalog.GetString ("4 x 3 Portrait (Book)"), 3.0 / 4.0),
-		new SelectionConstraint (Catalog.GetString ("4 x 6 Portrait (Postcard)"), 4.0 / 6.0),
-		new SelectionConstraint (Catalog.GetString ("5 x 7 Portrait (L, 2L)"), 5.0 / 7.0),
-		new SelectionConstraint (Catalog.GetString ("8 x 10 Portrait"), 8.0 / 10.0),
+//		new SelectionConstraint (Catalog.GetString ("4 x 3 Portrait (Book)"), 3.0 / 4.0),
+//		new SelectionConstraint (Catalog.GetString ("4 x 6 Portrait (Postcard)"), 4.0 / 6.0),
+//		new SelectionConstraint (Catalog.GetString ("5 x 7 Portrait (L, 2L)"), 5.0 / 7.0),
+//		new SelectionConstraint (Catalog.GetString ("8 x 10 Portrait"), 8.0 / 10.0),
 		new SelectionConstraint (Catalog.GetString ("Square"), 1.0)
 	};
 
@@ -341,7 +338,8 @@ public class PhotoView : EventBox {
 			if (redeye) {
 				Gdk.Rectangle area = new Gdk.Rectangle (x, y, width, height);
 				edited = PixbufUtils.RemoveRedeye (original_pixbuf, 
-								   area);
+								   area,
+								   (int) Preferences.Get (Preferences.EDIT_REDEYE_THRESHOLD));
 			} else { // Crop (I told you it was ugly)
 				edited = new Pixbuf (original_pixbuf.Colorspace, 
 						     original_pixbuf.HasAlpha, original_pixbuf.BitsPerSample,
@@ -370,7 +368,7 @@ public class PhotoView : EventBox {
 
 	private void HandleColorButtonClicked (object sender, EventArgs args) 
 	{
-		new FSpot.ColorDialog (photo_view);
+		ColorDialog.CreateForView (photo_view);
 	}	
 
 	int description_photo;
@@ -481,10 +479,8 @@ public class PhotoView : EventBox {
 		HBox inner_hbox = new HBox (false, 2);
 		//inner_hbox.BorderWidth = 6;
 
-		tag_view_box = new EventBox ();
-		tag_view = new TagView (tag_view_box);
-		tag_view_box.Add (tag_view);
-		inner_hbox.PackStart (tag_view_box, false, true, 0);
+		tag_view = new TagView ();
+		inner_hbox.PackStart (tag_view, false, true, 0);
 		SetColors ();
 
 		Label comment = new Label (Catalog.GetString ("Comment:"));
@@ -562,7 +558,7 @@ public class PhotoView : EventBox {
 	
 	private void SetColors ()
 	{
-		FSpot.Global.ModifyColors (tag_view_box);
+		FSpot.Global.ModifyColors (tag_view);
 		FSpot.Global.ModifyColors (photo_view);
 		FSpot.Global.ModifyColors (background);
 		FSpot.Global.ModifyColors (photo_view_scrolled);
